@@ -4,7 +4,8 @@ import ctypes
 import pyshorteners
 import random
 import time
-
+sm = "Hello! Enjoy using the Sime library"
+print(sm)
 class SimeLibraryError(Exception):
     pass
 
